package PNI::Node::Error;
use PNI::Mo;
extends 'PNI::Node';

sub BUILD {
    my $self = shift;
}

sub task { return; }

1;

